@@ -9,6 +9,12 @@
 # -------
 import os
 
+# requirements
+# ------------
+
+with open('requirements.txt') as f:
+    REQUIREMENTS = f.read().strip().split('\n')
+
 # config
 # ------
 try:
@@ -30,13 +36,13 @@ else:
 # ----
 setup(
     name="global_chem_extensions",
-    version="0.0.1",
+    version="0.0.2",
     packages=find_packages(),
     license='MPL 2.0',
     author="Suliman Sharif",
     author_email="sharifsuliman1@gmail.com",
     url="https://www.github.com/Sulstice/global-chem",
-    install_requires=[],
+    install_requires=REQUIREMENTS,
     long_description=long_description,
     long_description_content_type='text/markdown',
     zip_safe=False,
